#-----------------------------------------------------------------------
#	$Id: 05_reconnect.t,v 1.1 2005/11/25 13:07:27 pythontech Exp $
#	Should be able to disconnect then reconnect, with other process
#	adding something in between.
#-----------------------------------------------------------------------
use strict;
use Test::More tests => 2;

use lib 't/lib';
use DbUtil;

use PythonTech::Triples::DBHash;
use DB_File;

my $dbname = 't/new05.3db';

# With access = 'w', should create new db file
unlink($dbname);

if (open(CHILD,'-|')) {
    # Parent
    my $new = new PythonTech::Triples::DBHash(filename => $dbname,
					      access => 'wl');
    $new->add('foo','bar','baz');
    $new->commit;
    $new->disconnect; # close it

    # Child should now add a statement, print OK and exit
    chomp(my $exit = <CHILD>);
    is($exit,'OK', 'child exit');

    # Now add another statement ourselves
    $new->reconnect;
    $new->add('foo','bar','xyzzy');
    $new->commit;
    $new->disconnect; # close it
    $new = undef;
} else {
    # Child
    # Wait for db file to be initialised
    my $try;
    while (! -s $dbname) {
	if (++$try == 10) {
	    print "db file missing or empty after 10 seconds\n";
	    exit;
	}
	sleep 1;
    }
    sleep 1;

    my $triples = new PythonTech::Triples::DBHash(filename => $dbname,
						  access => 'wl');
    $triples->add('foo','bar','quux');
    $triples->commit;

    print "OK\n";
    exit;
}

my $expected = join('', map {"$_\n"} sort
		    'v1 = foo', 'ifoo = 1',
		    'v2 = bar', 'ibar = 2',
		    'v3 = baz', 'ibaz = 3',
		    'v4 = quux', 'iquux = 4',
		    'v5 = xyzzy', 'ixyzzy = 5',
		    'l = 5',
		    't1,2,3 = 1',
		    't1,2,4 = 1',
		    't1,2,5 = 1',
		    'o1,2 = 3+4+5',
		    's2,3 = 1',
		    's2,4 = 1',
		    's2,5 = 1');
is(&dbread($dbname), $expected, 'db data for 2 triples');

unlink($dbname);
